package Acme::MetaSyntactic::browser;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.001';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::browser - The "browser" theme

=head1 DESCRIPTION

Some famous web browsers.

Evolt.org maintains a browser archive at L<http://browsers.evolt.org/>.
The information in the archive was not used to create this list.

Wikipedia maintains a large list of web browsers at
L<https://en.wikipedia.org/wiki/List_of_web_browsers>.

=head1 CONTRIBUTORS

Philippe "BooK" Bruhat, Sébastien Aperghis-Tramoni, Rafaël Garcia-Suarez.

Introduced in Acme-MetaSyntactic version 0.05, published on January 16, 2005.

Updated in version 0.70, published on April 17, 2006.

Updated in version 0.96, published on October 16, 2006.

Updated with Google Chrome, and
received its own version number for Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

Updated with an C<=encoding> pod command in version 1.001,
published on May 14,2012

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
mozilla netscape msie mosaic links lynx w3m opera galeon konqueror safari
camino dillo amaya arachne omniweb planetweb voyager seamonkey iceweasel
chrome
