package Acme::MetaSyntactic::magicroundabout;
use strict;
use Acme::MetaSyntactic::Locale;
our @ISA = qw( Acme::MetaSyntactic::Locale );
our $VERSION = '1.001';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::magicroundabout - The Magic Round-About theme

=head1 DESCRIPTION

Characters from the Magic Round About children television series.

=head1 CONTRIBUTOR

Cédric Bouvier, C<< <cbouvi@cpan.org> >>.

Introduced in Acme-MetaSyntactic version 0.24, published on May 30, 2005.

Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

Updated with an C<=encoding> pod command in version 1.001,
published on May 14,2012

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::Locale>.

=cut

__DATA__
# default
en

# names fr
Ambroise
Azalee
Flappy
Margotte
Pollux
Zebulon

# names en
Brian
Dougal
Dylan
Ermintrude
Florence
Zebedee

