package Acme::MetaSyntactic::teletubbies;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
our $VERSION = '1.001';
__PACKAGE__->init();
1;

=encoding iso-8859-1

=head1 NAME

Acme::MetaSyntactic::teletubbies - The teletubbies theme

=head1 DESCRIPTION

Over the hills and far away, Teletubbies come to play.

=head1 CONTRIBUTOR

Philippe "BooK" Bruhat.

Introduced in Acme-MetaSyntactic version 0.23, published on May 23, 2005.

Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
published on May 7, 2012.

=head1 ACKNOWLEDGMENT

Thanks to Jérôme Fenal, for inspiration over IRC.

Updated with an C<=encoding> pod command in version 1.001,
published on May 14,2012

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Tinky_Winky Dipsy Laa_Laa Po
Noo_Noo Trumpets Baby_Sun Narrator
